# Waalaxy Connector

## About Waalaxy :

BreezyHR is a recruiting software that simplifies the process of attracting and hiring top talent. It offers a range of tools and features to make the hiring process more efficient and effective.

## Connector features :
            ),
- **trigger_view :**  Imports the visited profiles, in synchronization with the Waalaxy campaign (Visit + CRM Sync)

- **trigger_connexion :** Imports the profiles just connected with, in synchronisation with the Waalaxy campaign (Visit + Invitation + CRM Sync)


**Useful links:**

📄Visit [Waalaxy](https://www.waalaxy.com/) to learn more.

💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/connectors/waalaxy) on our Github.

**Screenshots :**
